pub struct ScopedTimer<'a> { /* private fields */ }Expand description
A simple timer that records elapsed time from its creation until it’s dropped.
If the enable_summary feature is active, it prints the elapsed time
when dropped.
Implementations
Sourceimpl<'a> ScopedTimer<'a>
impl<'a> ScopedTimer<'a>